pitchtools.PitchClassObjectSet
==============================

.. inheritance-diagram:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.copy

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.difference

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.intersection

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.isdisjoint

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.issubset

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.issuperset

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.symmetric_difference

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.union

    Inherited from :py:class:`__builtin__.frozenset`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__and__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__cmp__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__contains__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__eq__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__ge__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__gt__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__hash__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__iter__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__le__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__len__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__lt__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__ne__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__or__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__rand__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__repr__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__ror__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__rsub__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__rxor__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__sub__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__xor__

    Inherited from :py:class:`__builtin__.frozenset`
